----------------------------
cizsle | Cisco ZTP Server LE
----------------------------

*Zero-Touch Provisioning (ZTP) Server for Cisco Network Devices*

.. image:: https://travis-ci.org/CiscoDevNet/cizsle.svg?branch=master
    :target: https://travis-ci.org/CiscoDevNet/cizsle
.. image:: https://readthedocs.org/projects/cizsle/badge/?version=latest
    :target: https://cizsle.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://codecov.io/gh/CiscoDevNet/cizsle/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/CiscoDevNet/cizsle

------------------------------------------------------------------------------------------------------------------------

The goal of this project is to develop a Zero Touch Provisioning (ZTP) Server to simplify and accelerate deployment of
Cisco networking devices.

Project Targets
---------------

- Developed in Python
- Deployed in Docker containers

Key Features
------------

- Support ZTP on IOS XE, IOS XR, and NXOS devices
- Template and scripted device configurations
- Software image upgrades
- Topology validation
- Intuitive web UI and concise CLI
